@@ -324,3 +324,10 @@ class X_API:
             for ch in response:
                 f.write(ch)
             f.close()
+
+    def call_model_convert_path_status(
+            self,
+            post_data: str
+    ) -> Dict[str, Any]:
+        response = self._client.open_api_do("PUT", "model_convert/path/callback", "", json=post_data).json()
+        return response
