@@ -320,6 +320,8 @@ class Dataset(DatasetMeta):
         if storage_type not in {"local", "external"}:
             raise InvalidParamsError(param_name="storage_type", param_value=storage_type)
 
+        if storage_type == "external":
+            self._get_cloud_storage_config('', storage_type=storage_type)
         self.checkout(self._version)
         export_type = "annotation_uri" if self._annotation_status == 2 else "uri_json_standard"
 
@@ -367,7 +369,7 @@ class Dataset(DatasetMeta):
                 if len(items) < 2:
                     continue
 
-                s3_config = self._get_cloud_storage_config(items[0])
+                s3_config = self._get_cloud_storage_config(items[0], storage_type=storage_type)
 
                 file_name = download_helper.download_s3_file(
                     self._download_file,
@@ -572,7 +574,6 @@ class Dataset(DatasetMeta):
 
         if not CloudClient.find_s3_config(name):
             info = self._x_api.get_authorized_s3_config(name, storage_type)
-
             identifier = info["name"]
             endpoint = info["endpoint"]
             access_key = info["access_key"]
@@ -580,6 +581,8 @@ class Dataset(DatasetMeta):
             default_bucket = info["bucket"]
 
             CloudClient.set_s3_config(identifier, endpoint, access_key, secret_key, default_bucket)
+            if name != default_bucket:
+                CloudClient.set_s3_config(default_bucket, endpoint, access_key, secret_key, default_bucket)
         else:
             identifier = name
 
